<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Stretch</name>
    <message>
        <location filename="../Stretch.js" line="+59"/>
        <source>First corner</source>
        <translation>Primo punto dell&apos;angolo</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Reference point</source>
        <translation>Punto di riferimento</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Target point</source>
        <translatorcomment>--exact match--
--file: IsoProject_it.ts--
Punto finale
Obiettivo punto</translatorcomment>
        <translation>Obiettivo punto</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>No selected entities in given range</source>
        <translation>Nessun oggetto selezionato in un determinato intervallo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No entities in given range</source>
        <translation>Nessun oggetto in un determinato intervallo</translation>
    </message>
    <message>
        <location filename="../StretchInit.js" line="+2"/>
        <source>&amp;Stretch</source>
        <translation>&amp;Stira</translation>
    </message>
    <message>
        <location filename="../Stretch.js" line="-158"/>
        <source>Second corner</source>
        <translation>Secondo punto dell&apos;angolo</translation>
    </message>
</context>
</TS>
